#
# spec file for package libwebsockets
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover 12
Name:           libwebsockets
Version:        2.4.0
Release:        bp153.1.16
Summary:        A WebSockets library written in C
# base64-decode.c and ssl-http2.c is under MIT license with FPC exception.
# sha1-hollerbach is under BSD
# Test suite is licensed as Public domain (CC-zero)
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Url:            http://libwebsockets.org
Source:         https://github.com/warmcat/libwebsockets/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         %{name}-norpmtools.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Libwebsockets covers some features for people making embedded
HTTP/WebSocket servers or clients.

%package -n %{name}%{sover}
Summary:        A WebSockets library written in C
Group:          System/Libraries

%description -n %{name}%{sover}
Libwebsockets covers some features for people making embedded
HTTP/WebSocket servers or clients.

* HTTP(S) serving and client operation
* WS(S) serving and client operation
* HTTP(S) APIs for file transfer and upload
* HTTP POST form handling (including multipart)
* Cookie-based sessions
* Account management (including registration, email verification,
  lost password, etc.)
* SSL PFS support

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}

%description devel
This subpackage contains libraries and header files for developing
applications that want to make use of the WebSockets library.

%prep
%setup -q
%patch0 -p1

%build
%cmake \
    -DWITHOUT_TESTAPPS=1 \
    -DLWS_USE_LIBEV=OFF \
    -DLWS_WITHOUT_BUILTIN_GETIFADDRS=ON \
    -DLWS_USE_BUNDLED_ZLIB=OFF \
    -DLWS_WITHOUT_BUILTIN_SHA1=ON \
    -DLWS_WITH_STATIC=OFF \
    -DLWS_WITHOUT_TESTAPPS=ON
make %{?_smp_mflags}

%install
%cmake_install
rm -f %{buildroot}%{_libdir}/pkgconfig/libwebsockets_static.pc
rm -rf %{buildroot}%{_datadir}/libwebsockets-test-server/

%post -n libwebsockets%{sover} -p /sbin/ldconfig
%postun -n libwebsockets%{sover} -p /sbin/ldconfig

%files -n libwebsockets%{sover}
%defattr(-,root,root,-)
%doc LICENSE
%{_libdir}/libwebsockets.so.%{sover}

%files devel
%defattr(-,root,root,-)
%doc README.* changelog
%{_includedir}/*
%{_libdir}/libwebsockets.so
%{_libdir}/pkgconfig/libwebsockets.pc
%dir %{_libdir}/cmake/%{name}
%{_libdir}/cmake/%{name}/Libwebsockets*.cmake

%changelog
* Fri Oct 20 2017 mardnh@gmx.de
- Update to version 2.4.0
  * HTTP/2 server support is now mature and usable!  LWS_WITH_HTTP2=1 enables it.
    Uses ALPN to serve HTTP/2, HTTP/1 and ws[s] connections all from the same
    listen port seamlessly.  (Requires ALPN-capable OpenSSL 1.1 or mbedTLS).
  * LWS_WITH_MBEDTLS=1 at CMake now builds and works against mbedTLS instead of
    OpenSSL.  Most things work identically, although on common targets where
    OpenSSL has acceleration, mbedTLS is many times slower in operation.  However
    it is a lot smaller codewise.
  * Generic hash apis introduced that work the same on mbedTLS or OpenSSL backend
  * LWS_WITH_PEER_LIMITS tracks IPs across all vhosts and allows restrictions on
    both the number of simultaneous connections and wsi in use for any single IP
  * lws_ring apis provide a generic single- or multi-tail ringbuffer... mirror
    protocol now uses this.  Features include ring elements may be sized to fit
    structs in the ringbuffer, callback when no tail any longer needs an element
    and it can be deleted, and zerocopy options to write new members directly
    into the ringbuffer, and use the ringbuffer element by address too.
  * abstract ssh 2 server plugin included, with both plugin and standalone
    demos provided.  You can bind the plugin to a vhost and also serve full-
    strength ssh from the vhost.  IO from the ssh server is controlled by an
    "ops" struct of callbacks for tx, rx, auth etc.
  * Many fixes, cleanups, source refactors and other improvements.
- rebase patch:
  * libwebsockets-norpmtools.patch
* Sat Oct 14 2017 mardnh@gmx.de
- Do not build static libraries and test-apps
* Mon Oct  2 2017 jengelh@inai.de
- Extend description to say what libwebsockets really does.
  Replace -exec rm by simpler -delete.
- Move API documentation to libwebsockets-devel.
* Mon Oct  2 2017 mardnh@gmx.de
- Update to version 2.3.0
  * ESP32 OpenSSL support for client and server
  * ESP32 4 x WLAN credential slots may be configured
  * Libevent event loop support
  * SOCKS5 proxy support
  * lws_meta protocol for websocket connection multiplexing
  * lws_vhost_destroy() added... allows dynamic removal of listening
    vhosts.  Vhosts with shared listen sockets adopt the listen socket
    automatically if the owner is destroyed.
  * IPv6 on Windows
  * Improved CGI handling suitable for general CGI scripting, eg, PHP
  * Convert even the "old style" test servers to use statically included
    plugin sources
  * LWS_WITH_STATS cmake option dumps resource usage and timing information
    every few seconds to debug log, including latency information about
    delay from asking for writeable callback to getting it
  * Large (> 2GB) files may be served
  * LWS_WITH_HTTP_PROXY Cmake option adds proxying mounts
  * Workaround for libev build by disabling -Werror on the test app
  * HTTP2 support disabled since no way to serve websockets on it
* Sun Aug 20 2017 mardnh@gmx.de
- Add patch that disables spec-file creation and building rpm files
  within the CMake build system
  * libwebsockets-norpmtools.patch
* Tue May 30 2017 mardnh@gmx.de
- Fix Source URL
- Fix Group
- Trim description
- Rename %%soname to %%sover to better reflect its use
- Complete specfile overhaul
- Update to version 2.2.1
* Wed Sep 14 2016 ecsos@opensuse.org
- Update to version 1.7.8
* Thu May 21 2015 ancor@suse.com
- Updated to version 1.4
* Tue Nov 18 2014 perry.werneck@gmail.com
- Updating to latest version.
* Mon Mar 17 2014 prusnak@opensuse.org
- created package (version 1.23)
